(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     29680,        730]
NotebookOptionsPosition[     27503,        655]
NotebookOutlinePosition[     28149,        680]
CellTagsIndexPosition[     28062,        675]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Load the LGSBloch package", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input"],

Cell[BoxData["\<\"/Users/simon/Development/AtomicDensityMatrix/LGSBloch/\
LGSBloch\"\>"], "Output"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "LGSBloch`"}]], "Input"],

Cell["\<\
Generate the system of equations for the Na D2 line. (This can take a few \
minutes.)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NaD2LGS", "=", 
   RowBox[{"GenerateLGSSystem", "[", "]"}]}], ";"}]], "Input"],

Cell["\<\
 If you like, you can save the generated data to a file, so that you can \
recall it in the next Mathematica session with \
Get[ToFileName[NotebookDirectory[],\[CloseCurlyDoubleQuote]NaD2LGS.mx\
\[CloseCurlyDoubleQuote]]], without having to compute it again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<NaD2LGS.mx\>\""}], 
    "]"}], ",", "NaD2LGS"}], "]"}]], "Input"],

Cell[TextData[StyleBox["Comparison of cw excitation efficiency between cw and \
pulsed simulation routines\nRon Holzloehner, 01Dec11\n\n\
Let\[CloseCurlyQuote]s first set the environmental and laser parameters.",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"opt1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"IMeso", "\[Rule]", "78.48"}], ",", 
     RowBox[{"RepumpFraction", "\[Rule]", "0.1"}], ",", 
     RowBox[{"LightPolarization", "\[Rule]", "1."}], ",", 
     RowBox[{"BG", "\[Rule]", "0.4662"}], ",", 
     RowBox[{"MagneticZenith", "\[Rule]", 
      RowBox[{
       RowBox[{"61.0", "*", 
        RowBox[{"\[Pi]", "/", "180.0"}]}], "+", 
       RowBox[{"\[Pi]", "/", "2.0"}]}]}], ",", 
     RowBox[{"MagneticAzimuth", "\[Rule]", 
      RowBox[{"14.0", "*", 
       RowBox[{"\[Pi]", "/", "180.0"}]}]}], ",", 
     RowBox[{"FWHMbw", "\[Rule]", "0."}], ",", 
     RowBox[{"Zenith", "\[Rule]", "0."}], ",", 
     RowBox[{"Htele", "\[Rule]", "1284."}], ",", 
     RowBox[{"DLT", "\[Rule]", "0.2"}], ",", 
     RowBox[{"\[Mu]LT", "\[Rule]", "1."}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ta", "\[Rule]", "0.89"}], ",", 
     RowBox[{"HNa", "\[Rule]", 
      RowBox[{"95000.0", "+", "1284.0"}]}], ",", 
     RowBox[{"PLaunch", "\[Rule]", "49.9602"}]}], "}"}]}], ";"}]], "Input"],

Cell[TextData[StyleBox["Here\[CloseCurlyQuote]s the specific mesospheric \
return flux at I=IMeso=78.48 W/m^2",
 FontFamily->"Verdana"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PsiIMeso", "=", 
  RowBox[{"PsiMeso", "[", 
   RowBox[{"NaD2LGS", ",", "opt1"}], "]"}]}]], "Input"],

Cell[BoxData["273.8894367938223`"], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Set sodium coumn abundance [atoms/m^2]",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cNa", "=", "4.0*^13"}], ";"}]], "Input"],

Cell[TextData[StyleBox["Mesospheric spot FWHM and area [m]:",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"mySpotFWHM", "=", 
    RowBox[{"2", "*", "0.25"}]}], ";"}], "\[IndentingNewLine]", "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "w2FWHM", " ", "is", " ", "the", " ", "conversion", " ", "factor", " ", 
    "from", " ", "waist", " ", "radius", " ", "to", " ", "FWHM", " ", "of", 
    " ", "a", " ", "Gaussian", " ", "beam"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w2FWHM", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"2.0", "*", 
      RowBox[{"Log", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"w", " ", "is", " ", "the", " ", 
    RowBox[{"1", "/", 
     RowBox[{"e", "^", "2"}]}], " ", "radius", " ", "in", " ", "intensity"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{"mySpotFWHM", "/", "w2FWHM"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Effective", " ", "spot", " ", "area"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mySpotArea", "=", 
   RowBox[{"\[Pi]", " ", 
    RowBox[{"w", "^", "2"}]}]}], ";"}]}], "Input"],

Cell[TextData[StyleBox["\nCrude estimate of the expected return flux \
\[CapitalPhi] on the ground [W/m^2]\nFor the formula, see e.g. Eq(6) in \
Holzloehner et al., A&A (2010)\nNote that this assumes a sodium centroid of \
95km + 1.28km telescope altitude = 96.28 km which is quite high.",
 FontFamily->"Verdana"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Phi1", "=", 
  RowBox[{
   RowBox[{"PsiIMeso", "*", "IMeso", "*", "cNa", "*", "mySpotArea", "*", 
    RowBox[{"Ta", "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"HNa", "-", "Htele"}], ")"}], "^", "2"}]}]}], "/.", 
   "opt1"}]}]], "Input"],

Cell[BoxData["4.803651468302054`*^7"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["To obtain a realistic value of  \[CapitalPhi], we have to sample \
the return flux at a few irradiance levels. We compute a repository of such \
samples. By setting LaserSpotMesoFWHM directly, we bypass the computation of \
the mesospheric irradiances through DLT and MsqrLT etc.:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"optBeamRep", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"LaserSpotMesoFWHM", "\[Rule]", "mySpotFWHM"}], ",", 
     RowBox[{"NSamples", "\[Rule]", "12"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"rep1", "=", 
  RowBox[{"BeamRepository", "[", 
   RowBox[{"NaD2LGS", ",", "opt1", ",", "optBeamRep"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    TemplateBox[{RowBox[{
        StyleBox[
         TagBox["InterpolatingFunction", "SummaryHead"], 
         "NonInterpretableSummary"], 
        StyleBox["[", "NonInterpretableSummary"], 
        DynamicModuleBox[{Typeset`open$$ = False}, 
         PanelBox[
          PaneSelectorBox[{False -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquarePlusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{
                   GrayLevel[0.6], 
                   AbsolutePointSize[5], 
                   PointBox[{1, 1}], 
                   PointBox[{2, 4}], 
                   PointBox[{3, 2}], 
                   PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                 GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                   GrayLevel[0.7], 
                   Thickness[Tiny]], FrameTicks -> None, 
                 ImageSize -> {Automatic, 
                   Dynamic[
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "156.96750164103025`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}], True -> GridBox[{{
                PaneBox[
                 ButtonBox[
                  DynamicBox[
                   FEPrivate`FrontEndResource[
                   "FEBitmaps", "SquareMinusIconMedium"]], 
                  ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                  None, Evaluator -> Automatic, Method -> "Preemptive"], 
                 Alignment -> {Center, Center}, ImageSize -> 
                 Dynamic[{
                   Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                GraphicsBox[{{
                   GrayLevel[0.6], 
                   AbsolutePointSize[5], 
                   PointBox[{1, 1}], 
                   PointBox[{2, 4}], 
                   PointBox[{3, 2}], 
                   PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                 GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                   GrayLevel[0.7], 
                   Thickness[Tiny]], FrameTicks -> None, 
                 ImageSize -> {Automatic, 
                   Dynamic[
                   3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                GridBox[{{
                   RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "156.96750164103025`"}], "}"}], "}"}],
                     "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"BSpline\"", "SummaryItem"]}]}, {
                   RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                 False, GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                 GridBoxSpacings -> {
                  "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                 BaseStyle -> {
                  ShowStringCharacters -> False, NumberMarks -> False, 
                   PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
              GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              BaselinePosition -> {1, 1}]}, 
           Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
          Baseline], DynamicModuleValues :> {}], 
        StyleBox["]", "NonInterpretableSummary"]}]},
     "CopyTag",
     DisplayFunction->(#& ),
     InterpretationFunction->("InterpolatingFunction[{{0., 156.968}}, <>]"& )],
    False,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.35`", ",", "101.00351419040894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.705995685203725`", ",", "612.4531804492385`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5.638383172294527`", ",", "2249.7324265505235`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12.147162461272407`", ",", "4798.3846303442015`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21.23233355213737`", ",", "7908.286583792208`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"32.89389644488941`", ",", "11332.265620682267`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"47.13185113952852`", ",", "14924.668372280159`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"63.94619763605471`", ",", "18616.76267389563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"83.33693593446797`", ",", "22410.68005222204`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"105.30406603476833`", ",", "26353.54125207448`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"129.84758793695573`", ",", "30510.22713313148`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"156.96750164103025`", ",", "34895.88412735603`"}], "}"}]}], 
    "}"}], ",", "156.96750164103025`", ",", "0.5`"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["The vector of irradiance samples goes to 156.968 W/m^2 which is \
twice as much as the value of IMeso:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"156.96", "/", "IMeso"}], "/.", "opt1"}]], "Input"],

Cell[BoxData["2.`"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["The routine Sce performs the integration across the Gaussian beam:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Sce"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"Compute beam figure of merit \
\\!\\(\\*FormBox[SubscriptBox[\\(s\\), \\(ce\\)],\\nTraditionalForm]\\). Note \
that the following options may be changed from their values when \
BeamRepository[] was called, unless the peak intensity exceeds that of the \
interpolating function:\\n\\tPLaunch: Launched power [W]\\n\\tZenith: Zenith \
angle [rad]   (note that MagneticZenith and MagneticAzimuth cannot be \
changed!)\\n\\tHNa: Altitude of sodium centroid above sea level \
[m]\\n\\tHtele: Altitude of launch telescope above sea level [m]\\n\\tDLT: \
Launch telescope aperture [m]\\n\\t\[Mu]LT: Ratio of DLT to \\!\\(\\*FormBox[\
\\(1/\\*SuperscriptBox[\\(e\\), \\(2\\)]\\),\\nTraditionalForm]\\) lauch beam \
intensity diameter (not radius!), see Yura, Eq.(2.7)\\n\\tMsqrLT:  Effective \
\\!\\(\\*FormBox[SuperscriptBox[\\(M\\), \\(2\\)],\\nTraditionalForm]\\) beam \
quality factor out of the launch telescope, also taking into account the \
effect of speckles\\n\\tLaserSpotMesoFWHM: Mesospheric FWHM spot size [m]. If \
this option is set to a nonzero value, DLT and \[Mu]LT are not used to \
compute the mesospheric irradiance.\\n\\nOutput values:\\n\\tsceOut: Merit \
parameter \\!\\(\\*FormBox[SubscriptBox[\\(s\\), \
\\(ce\\)],\\nTraditionalForm]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\
\\\"Italic\\\"]\\)[ph/s/W/(atom/m^2)]\\n\\tGroundInt: Integrated flux on the \
ground [ph/s/atom]\\n\\tFluxMesoInt: Integrated flux in the mesosphere \
[ph*m^2/s/sr/atom]\\n\\tFWHMSpeckle: Instantaneous laser spot size in the \
mesosphere (central speckle) [m]\\n\\tFWHM2mom: Return light spot size based \
on second moment [m]\\n\\tIMesoMax: Peak mesospheric laser light intensity \
[W/m^2]\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info223688799903-7693732"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sce1", "=", 
  RowBox[{"Sce", "[", 
   RowBox[{"opt1", ",", 
    RowBox[{"rep1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
    ",", "optBeamRep"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "293.94651716717294`", ",", "1.2889180030984168`*^-6", ",", 
   "13070.207840408102`", ",", "0.5`", ",", "0.5532974396637778`", ",", 
   "156.96750164103025`", ",", "LGSBloch`Private`fitFunction$51041", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"LGSBloch`Private`Psi0$51041", "\[Rule]", "46949.91830335521`"}],
      ",", 
     RowBox[{"LGSBloch`Private`I0$51041", "\[Rule]", "142.40436357047295`"}], 
     ",", 
     RowBox[{"LGSBloch`Private`c$51041", "\[Rule]", "0.9007474404358663`"}]}],
     "}"}], ",", "0.011202438653208033`"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Multiply GroundInt (2nd return value in the above results list) by \
the column abundance to obtain the flux on the ground in ph/s/m^2:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Phi2", "=", 
  RowBox[{
   RowBox[{"sce1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
   "*", "cNa"}]}]], "Input"],

Cell[BoxData["5.1556720123936675`*^7"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Note that phi2 also agrees quite well with Phi1 further above. ",
  FontFamily->"Verdana"],
 "\n\n",
 StyleBox["We can compare these values to Rachel\[CloseCurlyQuote]s results \
from StepPulseFlux[] at 50W:\nAs we can see, there\[CloseCurlyQuote]s an \
agreement on both \[CapitalPhi]=52 Mph/s/m^2 and sce=296 ph/s/W/(atom/m^2). ",
  FontFamily->"Verdana"],
 "\n"
}], "Text"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {RGBColor[0, 0, 1], Thickness[0.003], LineBox[CompressedData["
1:eJxdkW1I00Ecx6eWmYR7oZn5sFqmpUvndM6pm/vO/55dMjQdRREZMzSGSVrK
1hQyQ7NA8oVKZmZSDmtGRoliFJZFqZT0oFKJpRVms1zQHsxs3asOjuO4u9/v
8/0cM68oS+dJo9ESVubf9f/heuvXarBbRaM7KcpOd4n+7ZdFynMxpSatL05E
ZtwJda6BPrqjO8/DH//O6bjQlMjxuRSEAVUBNe/0R2Ct/wZ9AAMm9/0NyNh/
95HPLSYEnjEstSME7bRy/S/1VvJ+Ey6zaXUj45F4t7esJsfFRI5urObjnihS
LxzfmfynyucsXOTvWapyRqBRPesxIYwlPNvQ+2a6rUMTh30BguIeRxR2n9fd
DDFxIHT3Y8F25Qa7/mo8QhfCZj7YY6CrqKwUDSeQ/mxE1uUE77Zy8W2moqvG
FYegxddPfP14hIeD/LVVncaoJIyMHclnuuLR0HRh+oWYT/gSoJC/k8Zqk3Hj
/oHNvU4ulOOrHnUVpKDFzZuI2+81kwXlqThryZrQOHn4NS15aaoWEP4k6LxL
GF71QuhbqIbPDj66tkhL1zWlkTzJCJ2aDLFcFGHnGW5mpSMFwZ8O05Y1IPlS
sfAstPjUc2BHeYRPkEOAo9l9iYsaMckrhJkxuE0zKsa6Q4EPLPY0sCTvLe3q
dJJfhCTuvVHb43QcM3sNtBsB8QtXtEpCER/AVOGwn3mAwkr45iKjGFzu57Jg
voT4EWMwxRzW1i1BbqPteKoxHdVzDXpqu5T4SseAXdDs3SqFjD6/a42RgtbZ
12wNkBF/FKIze9hetTLwqmc4YwYJvtbZZqW/Zbju9inBrPUho79Yjoilv8BS
TO23+hR+lBO/Uhy8Vno9O1eB9SWv5goNMpzeuHneOKQgvmWg/xg6+SVJidVz
I495Bjnmw8p8W64qiX856OF59uZAFX4eGOrwNCiQX9HVOVulIv+hQL+YoT35
Q4U/y+VsdQ==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       BaseStyle->{FontFamily -> "Verdana", 12},
       Frame->True,
       FrameLabel->{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"P\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"launch\\\"]\\)  [W]\"", TraditionalForm], 
         FormBox[
         "\"\[CapitalPhi]  [\\!\\(\\*SuperscriptBox[\\\"10\\\", \\\"6\\\"]\\) \
ph/s/\\!\\(\\*SuperscriptBox[\\\"m\\\", \\\"2\\\"]\\)]\"", TraditionalForm]},
       GridLines->Automatic,
       ImageSize->288,
       PlotLabel->FormBox[
         StyleBox[
         "\"Return Flux on Ground at \
\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"C\\\",\\nFontSlant->\\\"Italic\\\"], \\\
\"Na\\\"]\\) = 4.\[Times]\\!\\(\\*SuperscriptBox[\\\"10\\\", \\\"13\\\"]\\) \
atoms/\\!\\(\\*SuperscriptBox[\\\"m\\\", \\\"2\\\"]\\)\"", FontFamily -> 
          "Verdana", FontSize -> 12, StripOnInput -> False], TraditionalForm],
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {153.6, -94.93002067198384},
       ImageScaled[{0.5, 0.5}], {288, 177.9937887599697}], InsetBox[
      GraphicsBox[{{}, {}, 
        {RGBColor[0, 0, 1], Thickness[0.003], LineBox[CompressedData["
1:eJwtkX0s1HEcx3W3pBJbF2pUno7ykMhTncub8/yQJqkRo1aN6Pwe7s51Rw1r
042akBQaY83EejCrpNEapR0NWSo2uqV5yFZxD6yk7x/fffbd9/v5fl7v19fu
tDj+LMfIyMhrdf2ry1/M6hS6H4HvsoezVPlK/N//CfTVvDWNfHkJeU7RHTaG
DeiPfzxr/FxOzs3x5hN10HydHF1RGaI5Aw+lTXX2e8S5yF+7b4V6/kOXlEUZ
AjjurjF6axxyX0waKJWR/t3o7s34OHpAhvFTucXHl+2QyMuIUU5KyXsOGJJN
uHZUSVHrn7RSZODDJXr+5/bjUsLjjFynFrebllKkbAugnuj3wrLz5NzJzxII
1+a5YiRZ59HfKIHNwk7NlM4d9Q06ThYtIfM9oPK+NT0SJMG85nJL8fJ+8BIm
x9p5EsLjCbH10sbebyzUQznn7Ja9kO9w+9XAC5bwHYDQati5roJFa3e67VOD
NzRCi4ubxSxq1nh9ENLGK1uIZFHSFj921OALbmptjIcTS/j9sHCsL6SFyyK7
RlQ+rffH8My1C3GTDMlzEGZpahm3h0GsyvvIFf0heAqkivZ6huQTwPHZT1VC
EQM3Od9kuz4APq8Fl96fY0heIbintZW7ohiYnrfsadMdRhFz54rHPobkD4R1
rFCn3cpA2sztalACqVn8VzlamvgAyhKUBSXjNFbDV4uVQYj/lN0Q9pomfoLw
JXlWVN5CI7Hql0ygDIZ8JM9WXE4TX8GYD6wsHFTSCDOfS9igFCHTfoffo7M0
8SdCc3WrzCyOhu9VjeeQIgSsqun7hD+NB2s+QxCQtv+6nQMN/so/4FCkneh4
qd5CE7+hsOUIbKe0FCzYDzOZijDcMy64m/SVIr7DYJKxKd1zkML6GXWfryIc
UUu1I2c6KeI/HPab86rm71P4nd7byFFEwHFUK1dXUOQ/IlC3ciPXqJDCX2lQ
dpo=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       BaseStyle->{FontFamily -> "Verdana", 12},
       Frame->True,
       FrameLabel->{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"P\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"launch\\\"]\\)  [W]\"", TraditionalForm], 
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"s\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"ce\\\"]\\)  \
[ph/s/W/(atoms/\\!\\(\\*SuperscriptBox[\\\"m\\\", \\\"2\\\"]\\))]\"", 
          TraditionalForm]},
       GridLines->Automatic,
       ImageSize->288,
       PlotLabel->FormBox[
         StyleBox[
         "\"Laser format efficiency \\!\\(\\*SubscriptBox[\\nStyleBox[\\\"s\\\
\",\\nFontSlant->\\\"Italic\\\"], \\\"ce\\\"]\\) (\[Theta]=151.6 deg)\"", 
          FontFamily -> "Verdana", FontSize -> 12, StripOnInput -> False], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {460.79999999999995, -94.93002067198384},
       ImageScaled[{0.5, 0.5}], {288, 177.9937887599697}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {RGBColor[0, 0, 1], Thickness[0.003], LineBox[CompressedData["
1:eJw1kXss1WEYx11myoqd3IoTTpJczuLgkNvzcNzSIZcThRqZqCm15VLnUAuZ
sLS1VUSNtFY4m1qxcebyB8uJYmoh/V52TI7jsvHHuajQ7/fHu2fv3vd5n8/3
83Iu5CVkGejp6fG21nbV/TR9LlavgHtW92CKjIL/+79Q3zDhXzJAQfGRkx/Z
WmMMl+fnJg8x52bIe2vXvSmnQBZ9SaDSmiP3U2Kk5CsFJTv3rXGkXNH2Y4KC
QAOum1Bji/t6ajJtJpl+e4y6JW0KmaFgJq2o8rSOg53a3tn4WeY9RyzMcT0Q
M09Bo1/KZpnWCXmZc7+8FxkeZ0z9vVRjskzBOYvA6+81LuhQ1BA5ukZB0M48
N+SPKXeXbVDAXj2omFNzsetLWYeLmpl/DKumZEZ9OgqWFbdbK3UeKFuzfBet
R2geT5yvaDwzaEhgZPzaRY6Ohx3POst9jQnN54UyF5+eehMC7X0ZDl1ab2w1
YxWu7yXQsMPrg+nVM5xQFoEaacJknJaPC2UrjuUWhOb3xfhDsdM91gSuNAge
LWj8ULlY07xkQ+g8xzHbqljOsiMQU+Ude0fjj8Gs7pdcDqHzBWDvJOTjYQLu
N5127dcEop2i/260M6HzBmFx6VFToSuBPdlW/VJ1MM4WfBaFcwmdH9BidKaW
70Gg4I2hrFmCSE08VNt7EdoHoj8na0CfT2ArfF2eJARF1SKHaT/GTwg+6N6F
0gACSU/WCwMkobg2rh8nDmZ8heKwqkeMIQQizFQiY4kAT6mmlv4IGH8C/G4a
MPwhggD/nsJzXByGikbroJwTBNp2fIZhqKtTtrmQgNPmNnA4tlx9ldsZy/gN
R1thaV5yPAHLG9+Ul8UR2KRMq11NZHxH4H3hi+XSJAJGypEhvjgSY9Mfv2ad
ZfxHInuyaOppKoGNjMEWA3EUVowVNLPPM/8Rhe3Jctu6dAL/AHLBjGE=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0., 0.523},
       BaseStyle->{FontFamily -> "Verdana", 12},
       Frame->True,
       FrameLabel->{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"P\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"launch\\\"]\\)  [W]\"", TraditionalForm], 
         FormBox["\"FWHM  [m]\"", TraditionalForm]},
       GridLines->Automatic,
       ImageSize->288,
       PlotLabel->FormBox[
         StyleBox[
         "\"Mesospheric Return Spot Size (2nd moment)\"", FontFamily -> 
          "Verdana", FontSize -> 12, StripOnInput -> False], TraditionalForm],
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {153.6, -284.79006201595155},
       ImageScaled[{0.5, 0.5}], {288, 177.9937887599697}], 
     InsetBox["", {460.79999999999995, -284.79006201595155}, {
      Center, Center}, {287.99999999999994, 177.9937887599697}]}}, {}},
  ContentSelectable->True,
  ImageSize->{626.4, 391.72008268793536`},
  PlotRangePadding->{6, 5}]], "Print"]
},
WindowSize->{720, 852},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> True}},
ShowSelection->True,
TrackCellChangeTimes->False,
FrontEndVersion->"11.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info223688799903-7693732"->{
  Cell[17174, 434, 1799, 25, 390, "Print",
   CellTags->"Info223688799903-7693732"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info223688799903-7693732", 27953, 669}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 41, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[623, 24, 104, 2, 31, "Input"],
Cell[730, 28, 99, 1, 31, "Output"]
}, Open  ]],
Cell[844, 32, 53, 1, 31, "Input"],
Cell[900, 35, 109, 3, 26, "Text"],
Cell[1012, 40, 113, 3, 31, "Input"],
Cell[1128, 45, 282, 5, 41, "Text"],
Cell[1413, 52, 213, 6, 31, "Input"],
Cell[1629, 60, 246, 3, 87, "Text"],
Cell[1878, 65, 1065, 25, 89, "Input"],
Cell[2946, 92, 145, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[3116, 98, 123, 3, 31, "Input"],
Cell[3242, 103, 45, 0, 31, "Output"]
}, Open  ]],
Cell[3302, 106, 98, 1, 30, "Text"],
Cell[3403, 109, 75, 2, 31, "Input"],
Cell[3481, 113, 95, 1, 30, "Text"],
Cell[3579, 116, 1157, 32, 146, "Input"],
Cell[4739, 150, 323, 4, 106, "Text"],
Cell[CellGroupData[{
Cell[5087, 158, 272, 8, 31, "Input"],
Cell[5362, 168, 48, 0, 32, "Output"]
}, Open  ]],
Cell[5425, 171, 353, 7, 83, "Text"],
Cell[CellGroupData[{
Cell[5803, 182, 373, 10, 51, "Input"],
Cell[6179, 194, 10434, 210, 149, "Output"]
}, Open  ]],
Cell[16628, 407, 175, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[16828, 416, 85, 2, 31, "Input"],
Cell[16916, 420, 30, 0, 31, "Output"]
}, Open  ]],
Cell[16961, 423, 139, 4, 45, "Text"],
Cell[CellGroupData[{
Cell[17125, 431, 46, 1, 31, "Input"],
Cell[17174, 434, 1799, 25, 390, "Print",
 CellTags->"Info223688799903-7693732"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19010, 464, 205, 5, 31, "Input"],
Cell[19218, 471, 602, 13, 94, "Output"]
}, Open  ]],
Cell[19835, 487, 208, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[20068, 496, 152, 4, 31, "Input"],
Cell[20223, 502, 49, 0, 32, "Output"]
}, Open  ]],
Cell[20287, 505, 410, 10, 113, "Text"],
Cell[20700, 517, 6799, 136, 400, "Print"]
}
]
*)

